@@ -384,7 +384,6 @@ _cogl_atlas_texture_migrate_out_of_atlas (CoglAtlasTexture *atlas_tex)
                                 atlas_tex->rectangle.y + 1,
                                 atlas_tex->rectangle.width - 2,
                                 atlas_tex->rectangle.height - 2,
-                                COGL_TEXTURE_NO_ATLAS,
                                 atlas_tex->format);
   /* Note: we simply silently ignore failures to migrate a texture
    * out (most likely due to lack of memory) and hope for the
@@ -514,12 +513,13 @@ _cogl_atlas_texture_set_region_with_border (CoglAtlasTexture *atlas_tex,
 }
 
 static CoglBitmap *
-_cogl_atlas_texture_prepare_for_upload (CoglAtlasTexture *atlas_tex,
-                                        CoglBitmap *bmp,
-                                        CoglError **error)
+_cogl_atlas_texture_convert_bitmap_for_upload (CoglAtlasTexture *atlas_tex,
+                                               CoglBitmap *bmp,
+                                               CoglBool can_convert_in_place,
+                                               CoglError **error)
 {
   CoglPixelFormat internal_format;
-  CoglBitmap *converted_bmp;
+  CoglBitmap *upload_bmp;
   CoglBitmap *override_bmp;
 
   /* We'll prepare to upload using the format of the actual texture of
@@ -533,15 +533,11 @@ _cogl_atlas_texture_prepare_for_upload (CoglAtlasTexture *atlas_tex,
   internal_format = (COGL_PIXEL_FORMAT_RGBA_8888 |
                      (atlas_tex->format & COGL_PREMULT_BIT));
 
-  converted_bmp = _cogl_texture_prepare_for_upload (bmp,
-                                                    internal_format,
-                                                    NULL, /* dst_format_out */
-                                                    NULL, /* glintformat */
-                                                    NULL, /* glformat */
-                                                    NULL, /* gltype */
-                                                    error);
-
-  if (converted_bmp == NULL)
+  upload_bmp = _cogl_bitmap_convert_for_upload (bmp,
+                                                internal_format,
+                                                can_convert_in_place,
+                                                error);
+  if (upload_bmp == NULL)
     return NULL;
 
   /* We'll create another bitmap which uses the same data but
@@ -549,14 +545,14 @@ _cogl_atlas_texture_prepare_for_upload (CoglAtlasTexture *atlas_tex,
      to the atlas texture won't trigger the conversion again */
 
   override_bmp =
-    _cogl_bitmap_new_shared (converted_bmp,
-                             cogl_bitmap_get_format (converted_bmp) &
+    _cogl_bitmap_new_shared (upload_bmp,
+                             cogl_bitmap_get_format (upload_bmp) &
                              ~COGL_PREMULT_BIT,
-                             cogl_bitmap_get_width (converted_bmp),
-                             cogl_bitmap_get_height (converted_bmp),
-                             cogl_bitmap_get_rowstride (converted_bmp));
+                             cogl_bitmap_get_width (upload_bmp),
+                             cogl_bitmap_get_height (upload_bmp),
+                             cogl_bitmap_get_rowstride (upload_bmp));
 
-  cogl_object_unref (converted_bmp);
+  cogl_object_unref (upload_bmp);
 
   return override_bmp;
 }
@@ -583,11 +579,13 @@ _cogl_atlas_texture_set_region (CoglTexture *tex,
   if (atlas_tex->atlas)
     {
       CoglBool ret;
-
-      bmp = _cogl_atlas_texture_prepare_for_upload (atlas_tex,
-                                                    bmp,
-                                                    error);
-      if (!bmp)
+      CoglBitmap *upload_bmp =
+        _cogl_atlas_texture_convert_bitmap_for_upload (atlas_tex,
+                                                       bmp,
+                                                       FALSE, /* can't convert
+                                                                 in place */
+                                                       error);
+      if (!upload_bmp)
         return FALSE;
 
       /* Upload the data ignoring the premult bit */
@@ -595,10 +593,10 @@ _cogl_atlas_texture_set_region (CoglTexture *tex,
                                                         src_x, src_y,
                                                         dst_x, dst_y,
                                                         dst_width, dst_height,
-                                                        bmp,
+                                                        upload_bmp,
                                                         error);
 
-      cogl_object_unref (bmp);
+      cogl_object_unref (upload_bmp);
 
       return ret;
     }
@@ -648,42 +646,14 @@ _cogl_atlas_texture_can_use_format (CoglPixelFormat format)
 }
 
 CoglAtlasTexture *
-_cogl_atlas_texture_new_with_size (CoglContext *ctx,
-                                   int width,
-                                   int height,
-                                   CoglTextureFlags flags,
-                                   CoglPixelFormat internal_format,
-                                   CoglError **error)
+cogl_atlas_texture_new_with_size (CoglContext *ctx,
+                                  int width,
+                                  int height,
+                                  CoglPixelFormat internal_format,
+                                  CoglError **error)
 {
   CoglAtlasTexture *atlas_tex;
 
-  /* Don't put textures in the atlas if the user has explicitly
-     requested to disable it */
-  if (G_UNLIKELY (COGL_DEBUG_ENABLED (COGL_DEBUG_DISABLE_ATLAS)))
-    {
-      _cogl_set_error (error,
-                       COGL_SYSTEM_ERROR,
-                       COGL_SYSTEM_ERROR_UNSUPPORTED,
-                       "Atlasing disabled");
-      return NULL;
-    }
-
-  /* We can't put the texture in the atlas if there are any special
-     flags. This precludes textures with COGL_TEXTURE_NO_ATLAS and
-     COGL_TEXTURE_NO_SLICING from being atlased */
-  if (flags)
-    {
-      /* XXX: This is a bit of an odd error; if we make this api
-       * public then this should probably be dealt with at a higher
-       * level, in cogl-auto-texture.c:cogl_texture_new_with_size().
-       */
-      _cogl_set_error (error,
-                       COGL_SYSTEM_ERROR,
-                       COGL_SYSTEM_ERROR_UNSUPPORTED,
-                       "Usage constraints preclude atlasing texture");
-      return NULL;
-    }
-
   /* We can't atlas zero-sized textures because it breaks the atlas
      data structure */
   if (width < 1 || height < 1)
@@ -790,13 +760,13 @@ _cogl_atlas_texture_allocate (CoglTexture *tex,
 
 CoglAtlasTexture *
 _cogl_atlas_texture_new_from_bitmap (CoglBitmap *bmp,
-                                     CoglTextureFlags flags,
                                      CoglPixelFormat internal_format,
+                                     CoglBool can_convert_in_place,
                                      CoglError **error)
 {
   CoglContext *ctx = _cogl_bitmap_get_context (bmp);
   CoglAtlasTexture *atlas_tex;
-  CoglBitmap *dst_bmp;
+  CoglBitmap *upload_bmp;
   int bmp_width;
   int bmp_height;
   CoglPixelFormat bmp_format;
@@ -810,10 +780,10 @@ _cogl_atlas_texture_new_from_bitmap (CoglBitmap *bmp,
   internal_format = _cogl_texture_determine_internal_format (bmp_format,
                                                              internal_format);
 
-  atlas_tex = _cogl_atlas_texture_new_with_size (ctx,
-                                                 bmp_width, bmp_height,
-                                                 flags, internal_format,
-                                                 error);
+  atlas_tex = cogl_atlas_texture_new_with_size (ctx,
+                                                bmp_width, bmp_height,
+                                                internal_format,
+                                                error);
   if (!atlas_tex)
     return NULL;
 
@@ -823,10 +793,12 @@ _cogl_atlas_texture_new_from_bitmap (CoglBitmap *bmp,
       return NULL;
     }
 
-  dst_bmp = _cogl_atlas_texture_prepare_for_upload (atlas_tex,
-                                                    bmp,
-                                                    error);
-  if (dst_bmp == NULL)
+  upload_bmp =
+    _cogl_atlas_texture_convert_bitmap_for_upload (atlas_tex,
+                                                   bmp,
+                                                   can_convert_in_place,
+                                                   error);
+  if (upload_bmp == NULL)
     {
       cogl_object_unref (atlas_tex);
       return NULL;
@@ -841,15 +813,83 @@ _cogl_atlas_texture_new_from_bitmap (CoglBitmap *bmp,
                                                    0, /* dst_y */
                                                    bmp_width, /* dst_width */
                                                    bmp_height, /* dst_height */
-                                                   dst_bmp,
+                                                   upload_bmp,
                                                    error))
     {
-      cogl_object_unref (dst_bmp);
+      cogl_object_unref (upload_bmp);
       cogl_object_unref (atlas_tex);
       return NULL;
     }
 
-  cogl_object_unref (dst_bmp);
+  cogl_object_unref (upload_bmp);
+
+  return atlas_tex;
+}
+
+CoglAtlasTexture *
+cogl_atlas_texture_new_from_bitmap (CoglBitmap *bmp,
+                                    CoglPixelFormat internal_format,
+                                    CoglError **error)
+{
+  return _cogl_atlas_texture_new_from_bitmap (bmp, internal_format,
+                                              FALSE, error);
+}
+
+CoglAtlasTexture *
+cogl_atlas_texture_new_from_data (CoglContext *ctx,
+                                  int width,
+                                  int height,
+                                  CoglPixelFormat format,
+                                  CoglPixelFormat internal_format,
+                                  int rowstride,
+                                  const uint8_t *data,
+                                  CoglError **error)
+{
+  CoglBitmap *bmp;
+  CoglAtlasTexture *atlas_tex;
+
+  _COGL_RETURN_VAL_IF_FAIL (format != COGL_PIXEL_FORMAT_ANY, NULL);
+  _COGL_RETURN_VAL_IF_FAIL (data != NULL, NULL);
+
+  /* Rowstride from width if not given */
+  if (rowstride == 0)
+    rowstride = width * _cogl_pixel_format_get_bytes_per_pixel (format);
+
+  /* Wrap the data into a bitmap */
+  bmp = cogl_bitmap_new_for_data (ctx,
+                                  width, height,
+                                  format,
+                                  rowstride,
+                                  (uint8_t *) data);
+
+  atlas_tex = cogl_atlas_texture_new_from_bitmap (bmp, internal_format, error);
+
+  cogl_object_unref (bmp);
+
+  return atlas_tex;
+}
+
+CoglAtlasTexture *
+cogl_atlas_texture_new_from_file (CoglContext *ctx,
+                                  const char *filename,
+                                  CoglPixelFormat internal_format,
+                                  CoglError **error)
+{
+  CoglBitmap *bmp;
+  CoglAtlasTexture *atlas_tex = NULL;
+
+  _COGL_RETURN_VAL_IF_FAIL (error == NULL || *error == NULL, NULL);
+
+  bmp = cogl_bitmap_new_from_file (filename, error);
+  if (bmp == NULL)
+    return NULL;
+
+  atlas_tex = _cogl_atlas_texture_new_from_bitmap (bmp,
+                                                   internal_format,
+                                                   TRUE, /* convert in-place */
+                                                   error);
+
+  cogl_object_unref (bmp);
 
   return atlas_tex;
 }
