@@ -332,6 +332,7 @@ cogl_renderer_remove_constraint (CoglRenderer *renderer,
  * @COGL_DRIVER_GL3: An OpenGL driver using the core GL 3.1 profile
  * @COGL_DRIVER_GLES1: An OpenGL ES 1.1 driver.
  * @COGL_DRIVER_GLES2: An OpenGL ES 2.0 driver.
+ * @COGL_DRIVER_WEBGL: A WebGL driver.
  *
  * Identifiers for underlying hardware drivers that may be used by
  * Cogl for rendering.
@@ -346,7 +347,8 @@ typedef enum
   COGL_DRIVER_GL,
   COGL_DRIVER_GL3,
   COGL_DRIVER_GLES1,
-  COGL_DRIVER_GLES2
+  COGL_DRIVER_GLES2,
+  COGL_DRIVER_WEBGL
 } CoglDriver;
 
 /**
