@@ -332,9 +332,9 @@ _cogl_texture_2d_sliced_set_waste (CoglTexture2DSliced *tex_2ds,
 }
 
 static CoglBool
-_cogl_texture_2d_sliced_upload_to_gl (CoglTexture2DSliced *tex_2ds,
-                                      CoglBitmap *bmp,
-                                      CoglError **error)
+_cogl_texture_2d_sliced_upload_bitmap (CoglTexture2DSliced *tex_2ds,
+                                       CoglBitmap *bmp,
+                                       CoglError **error)
 {
   CoglSpan *x_span;
   CoglSpan *y_span;
@@ -422,17 +422,15 @@ _cogl_texture_2d_sliced_upload_to_gl (CoglTexture2DSliced *tex_2ds,
 }
 
 static CoglBool
-_cogl_texture_2d_sliced_upload_subregion_to_gl (CoglTexture2DSliced *tex_2ds,
-                                                int src_x,
-                                                int src_y,
-                                                int dst_x,
-                                                int dst_y,
-                                                int width,
-                                                int height,
-                                                CoglBitmap *source_bmp,
-                                                GLuint source_gl_format,
-                                                GLuint source_gl_type,
-                                                CoglError **error)
+_cogl_texture_2d_sliced_upload_subregion (CoglTexture2DSliced *tex_2ds,
+                                          int src_x,
+                                          int src_y,
+                                          int dst_x,
+                                          int dst_y,
+                                          int width,
+                                          int height,
+                                          CoglBitmap *source_bmp,
+                                          CoglError **error)
 {
   CoglTexture *tex = COGL_TEXTURE (tex_2ds);
   CoglSpan *x_span;
@@ -667,16 +665,13 @@ _cogl_texture_2d_sliced_setup_spans (CoglContext *ctx,
                                      int width,
                                      int height,
                                      int max_waste,
-                                     CoglPixelFormat format,
+                                     CoglPixelFormat internal_format,
                                      CoglError **error)
 {
   int max_width;
   int max_height;
   int n_x_slices;
   int n_y_slices;
-  GLenum gl_intformat;
-  GLenum gl_format;
-  GLenum gl_type;
 
   int   (*slices_for_size) (int, int, int, GArray*);
 
@@ -694,25 +689,16 @@ _cogl_texture_2d_sliced_setup_spans (CoglContext *ctx,
       slices_for_size = _cogl_pot_slices_for_size;
     }
 
-  ctx->driver_vtable->pixel_format_to_gl (ctx,
-                                          format,
-                                          &gl_intformat,
-                                          &gl_format,
-                                          &gl_type);
-
   /* Negative number means no slicing forced by the user */
   if (max_waste <= -1)
     {
       CoglSpan span;
 
       /* Check if size supported else bail out */
-      if (!ctx->texture_driver->size_supported (ctx,
-                                                GL_TEXTURE_2D,
-                                                gl_intformat,
-                                                gl_format,
-                                                gl_type,
-                                                max_width,
-                                                max_height))
+      if (!ctx->driver_vtable->texture_2d_can_create (ctx,
+                                                      max_width,
+                                                      max_height,
+                                                      internal_format))
         {
           _cogl_set_error (error,
                            COGL_TEXTURE_ERROR,
@@ -749,13 +735,10 @@ _cogl_texture_2d_sliced_setup_spans (CoglContext *ctx,
   else
     {
       /* Decrease the size of largest slice until supported by GL */
-      while (!ctx->texture_driver->size_supported (ctx,
-                                                   GL_TEXTURE_2D,
-                                                   gl_intformat,
-                                                   gl_format,
-                                                   gl_type,
-                                                   max_width,
-                                                   max_height))
+      while (!ctx->driver_vtable->texture_2d_can_create (ctx,
+                                                         max_width,
+                                                         max_height,
+                                                         internal_format))
         {
           /* Alternate between width and height */
           if (max_width > max_height)
@@ -973,18 +956,15 @@ _cogl_texture_2d_sliced_allocate (CoglTexture *tex,
 
 CoglTexture2DSliced *
 _cogl_texture_2d_sliced_new_from_bitmap (CoglBitmap *bmp,
-                                         CoglTextureFlags flags,
+                                         int max_waste,
                                          CoglPixelFormat internal_format,
+                                         CoglBool can_convert_in_place,
                                          CoglError **error)
 {
   CoglContext *ctx;
   CoglTexture2DSliced *tex_2ds;
-  CoglBitmap *dst_bmp;
-  GLenum gl_intformat;
-  GLenum gl_format;
-  GLenum gl_type;
-  int width, height, max_waste;
-  int i;
+  CoglBitmap *upload_bmp;
+  int width, height;
 
   _COGL_RETURN_VAL_IF_FAIL (cogl_is_bitmap (bmp), NULL);
 
@@ -996,19 +976,15 @@ _cogl_texture_2d_sliced_new_from_bitmap (CoglBitmap *bmp,
   /* Create new texture and fill with loaded data */
   tex_2ds = g_new0 (CoglTexture2DSliced, 1);
 
-  if (flags & COGL_TEXTURE_NO_SLICING)
-    max_waste = -1;
-  else
-    max_waste = COGL_TEXTURE_MAX_WASTE;
+  internal_format =
+    _cogl_texture_determine_internal_format (cogl_bitmap_get_format (bmp),
+                                             internal_format);
 
-  dst_bmp = _cogl_texture_prepare_for_upload (bmp,
-                                              internal_format,
-                                              &internal_format,
-                                              &gl_intformat,
-                                              &gl_format,
-                                              &gl_type,
-                                              error);
-  if (dst_bmp == NULL)
+  upload_bmp = _cogl_bitmap_convert_for_upload (bmp,
+                                                internal_format,
+                                                can_convert_in_place,
+                                                error);
+  if (upload_bmp == NULL)
     {
       _cogl_texture_2d_sliced_free (tex_2ds);
       return NULL;
@@ -1027,33 +1003,34 @@ _cogl_texture_2d_sliced_new_from_bitmap (CoglBitmap *bmp,
   if (!cogl_texture_allocate (COGL_TEXTURE (tex_2ds), error))
     goto error;
 
-  if (!_cogl_texture_2d_sliced_upload_to_gl (tex_2ds,
-                                             dst_bmp,
-                                             error))
+  if (!_cogl_texture_2d_sliced_upload_bitmap (tex_2ds,
+                                              upload_bmp,
+                                              error))
     goto error;
 
-  cogl_object_unref (dst_bmp);
-
-  if ((flags & COGL_TEXTURE_NO_AUTO_MIPMAP))
-    for (i = 0; i < tex_2ds->slice_textures->len; i++)
-      {
-        CoglPrimitiveTexture *slice_tex;
-
-        slice_tex = g_array_index (tex_2ds->slice_textures,
-                                   CoglPrimitiveTexture *,
-                                   i);
-
-        cogl_primitive_texture_set_auto_mipmap (slice_tex, FALSE);
-      }
+  cogl_object_unref (upload_bmp);
 
   return _cogl_texture_2d_sliced_object_new (tex_2ds);
 
  error:
-  cogl_object_unref (dst_bmp);
+  cogl_object_unref (upload_bmp);
   _cogl_texture_2d_sliced_free (tex_2ds);
   return NULL;
 }
 
+CoglTexture2DSliced *
+cogl_texture_2d_sliced_new_from_bitmap (CoglBitmap *bmp,
+                                        int max_waste,
+                                        CoglPixelFormat internal_format,
+                                        CoglError **error)
+{
+  return _cogl_texture_2d_sliced_new_from_bitmap (bmp,
+                                                  max_waste,
+                                                  internal_format,
+                                                  FALSE,
+                                                  error);
+}
+
 CoglTexture2DSliced *
 _cogl_texture_2d_sliced_new_from_foreign (CoglContext *ctx,
                                           unsigned int gl_handle,
@@ -1146,6 +1123,70 @@ _cogl_texture_2d_sliced_new_from_foreign (CoglContext *ctx,
   return _cogl_texture_2d_sliced_object_new (tex_2ds);
 }
 
+CoglTexture2DSliced *
+cogl_texture_2d_sliced_new_from_data (CoglContext *ctx,
+                                      int width,
+                                      int height,
+                                      int max_waste,
+                                      CoglPixelFormat format,
+                                      CoglPixelFormat internal_format,
+                                      int rowstride,
+                                      const uint8_t *data,
+                                      CoglError **error)
+{
+  CoglBitmap *bmp;
+  CoglTexture2DSliced *tex_2ds;
+
+  _COGL_RETURN_VAL_IF_FAIL (format != COGL_PIXEL_FORMAT_ANY, NULL);
+  _COGL_RETURN_VAL_IF_FAIL (data != NULL, NULL);
+
+  /* Rowstride from width if not given */
+  if (rowstride == 0)
+    rowstride = width * _cogl_pixel_format_get_bytes_per_pixel (format);
+
+  /* Wrap the data into a bitmap */
+  bmp = cogl_bitmap_new_for_data (ctx,
+                                  width, height,
+                                  format,
+                                  rowstride,
+                                  (uint8_t *) data);
+
+  tex_2ds = cogl_texture_2d_sliced_new_from_bitmap (bmp, max_waste,
+                                                    internal_format,
+                                                    error);
+
+  cogl_object_unref (bmp);
+
+  return tex_2ds;
+}
+
+CoglTexture2DSliced *
+cogl_texture_2d_sliced_new_from_file (CoglContext *ctx,
+                                      const char *filename,
+                                      int max_waste,
+                                      CoglPixelFormat internal_format,
+                                      CoglError **error)
+{
+  CoglBitmap *bmp;
+  CoglTexture2DSliced *tex_2ds = NULL;
+
+  _COGL_RETURN_VAL_IF_FAIL (error == NULL || *error == NULL, NULL);
+
+  bmp = _cogl_bitmap_from_file (ctx, filename, error);
+  if (bmp == NULL)
+    return NULL;
+
+  tex_2ds = _cogl_texture_2d_sliced_new_from_bitmap (bmp,
+                                           max_waste,
+                                           internal_format,
+                                           TRUE, /* can convert in-place */
+                                           error);
+
+  cogl_object_unref (bmp);
+
+  return tex_2ds;
+}
+
 static CoglBool
 _cogl_texture_2d_sliced_is_foreign (CoglTexture *tex)
 {
@@ -1359,32 +1400,24 @@ _cogl_texture_2d_sliced_set_region (CoglTexture *tex,
                                     CoglError **error)
 {
   CoglTexture2DSliced *tex_2ds = COGL_TEXTURE_2D_SLICED (tex);
-  GLenum gl_format;
-  GLenum gl_type;
+  CoglBitmap *upload_bmp;
   CoglBool status;
 
-  bmp = _cogl_texture_prepare_for_upload (bmp,
-                                          cogl_texture_get_format (tex),
-                                          NULL,
-                                          NULL,
-                                          &gl_format,
-                                          &gl_type,
-                                          error);
-  if (!bmp)
+  upload_bmp = _cogl_bitmap_convert_for_upload (bmp,
+                                                cogl_texture_get_format (tex),
+                                                FALSE, /* can't convert in
+                                                          place */
+                                                error);
+  if (!upload_bmp)
     return FALSE;
 
-  /* Send data to GL */
-  status =
-    _cogl_texture_2d_sliced_upload_subregion_to_gl (tex_2ds,
-                                                    src_x, src_y,
-                                                    dst_x, dst_y,
-                                                    dst_width, dst_height,
-                                                    bmp,
-                                                    gl_format,
-                                                    gl_type,
-                                                    error);
-
-  cogl_object_unref (bmp);
+  status = _cogl_texture_2d_sliced_upload_subregion (tex_2ds,
+                                                     src_x, src_y,
+                                                     dst_x, dst_y,
+                                                     dst_width, dst_height,
+                                                     upload_bmp,
+                                                     error);
+  cogl_object_unref (upload_bmp);
 
   return status;
 }
