@@ -31,13 +31,11 @@
 #ifndef __COGL_TEXTURE_3D_H
 #define __COGL_TEXTURE_3D_H
 
-#include <glib.h>
-
-G_BEGIN_DECLS
+COGL_BEGIN_DECLS
 
 /**
  * SECTION:cogl-texture-3d
- * @short_description: Fuctions for creating and manipulating 3D textures
+ * @short_description: Functions for creating and manipulating 3D textures
  *
  * These functions allow 3D textures to be used. 3D textures can be
  * thought of as layers of 2D images arranged into a cuboid
@@ -57,18 +55,23 @@ typedef struct _CoglTexture3D CoglTexture3D;
  * @depth: depth of the texture in pixels.
  * @internal_format: the #CoglPixelFormat to use for the GPU
  *    storage of the texture.
- * @error: A GError return location.
  *
- * Creates a new Cogl 3D texture with the specified dimensions and
- * pixel format.
+ * Creates a new #CoglTexture3D texture with the specified dimensions
+ * and pixel format.
  *
- * Note that this function will throw a #GError if
- * %COGL_FEATURE_TEXTURE_3D is not advertised. It can also fail if the
- * requested dimensions are not supported by the GPU.
+ * The storage for the texture is not allocated before this function
+ * returns. You can call cogl_texture_allocate() to explicitly
+ * allocate the underlying storage or preferably let Cogl
+ * automatically allocate storage lazily when it may know more about
+ * how the texture is going to be used and can optimize how it is
+ * allocated.
  *
- * Return value: a new #CoglTexture3D object or
- *               %NULL on failure and an exception will be returned
- *               in @error.
+ * <note>This texture will fail to allocate later if
+ * %COGL_FEATURE_ID_TEXTURE_3D is not advertised. Allocation can also
+ * fail if the requested dimensions are not supported by the
+ * GPU.</note>
+ *
+ * Returns: A new #CoglTexture3D object with no storage yet allocated.
  * Since: 1.10
  * Stability: Unstable
  */
@@ -77,8 +80,7 @@ cogl_texture_3d_new_with_size (CoglContext *context,
                                int width,
                                int height,
                                int depth,
-                               CoglPixelFormat  internal_format,
-                               GError **error);
+                               CoglPixelFormat internal_format);
 
 /**
  * cogl_texture_3d_new_from_data:
@@ -103,14 +105,14 @@ cogl_texture_3d_new_with_size (CoglContext *context,
  *    rows. Alternatively 0 can be passed to infer the @image_stride
  *    from the @height.
  * @data: pointer the memory region where the source buffer resides
- * @error: A GError return location.
+ * @error: A CoglError return location.
  *
  * Creates a new 3D texture and initializes it with @data. The data is
  * assumed to be packed array of @depth images. There can be padding
  * between the images using @image_stride.
  *
- * Note that this function will throw a #GError if
- * %COGL_FEATURE_TEXTURE_3D is not advertised. It can also fail if the
+ * Note that this function will throw a #CoglError if
+ * %COGL_FEATURE_ID_TEXTURE_3D is not advertised. It can also fail if the
  * requested dimensions are not supported by the GPU.
  *
  * Return value: the newly created #CoglTexture3D or %NULL if
@@ -129,7 +131,7 @@ cogl_texture_3d_new_from_data (CoglContext *context,
                                int rowstride,
                                int image_stride,
                                const uint8_t *data,
-                               GError **error);
+                               CoglError **error);
 
 /**
  * cogl_texture_3d_new_from_bitmap:
@@ -144,7 +146,7 @@ cogl_texture_3d_new_from_data (CoglContext *context,
  *    is if you have non-premultiplied source data and are going to adjust
  *    the blend mode (see cogl_pipeline_set_blend()) or use the data for
  *    something other than straight blending.
- * @error: A GError return location.
+ * @error: A CoglError return location.
  *
  * Creates a new 3D texture and initializes it with the images in
  * @bitmap. The images are assumed to be packed together after one
@@ -163,7 +165,7 @@ cogl_texture_3d_new_from_bitmap (CoglBitmap *bitmap,
                                  unsigned int height,
                                  unsigned int depth,
                                  CoglPixelFormat internal_format,
-                                 GError **error);
+                                 CoglError **error);
 
 /**
  * cogl_is_texture_3d:
@@ -180,6 +182,6 @@ cogl_texture_3d_new_from_bitmap (CoglBitmap *bitmap,
 CoglBool
 cogl_is_texture_3d (void *object);
 
-G_END_DECLS
+COGL_END_DECLS
 
 #endif /* __COGL_TEXTURE_3D_H */
