@@ -21,15 +21,15 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 
 #include <string.h>
 #include <math.h>
 #include <stdlib.h>
-#include <glib/gi18n-lib.h>
 
+#define COGL_VERSION_MIN_REQUIRED COGL_VERSION_1_4
+
+#include "cogl-i18n-private.h"
 #include "cogl-debug.h"
 #include "cogl-util.h"
 #include "cogl-context-private.h"
@@ -390,8 +390,10 @@ cogl_begin_gl (void)
    * values.
    */
   pipeline = cogl_get_source ();
-  _cogl_pipeline_flush_gl_state (pipeline,
+  _cogl_pipeline_flush_gl_state (ctx,
+                                 pipeline,
                                  cogl_get_draw_framebuffer (),
+                                 FALSE,
                                  FALSE);
 
   /* Disable any cached vertex arrays */
@@ -746,8 +748,10 @@ _cogl_init (void)
 
   if (initialized == FALSE)
     {
+#ifdef ENABLE_NLS
       bindtextdomain (GETTEXT_PACKAGE, COGL_LOCALEDIR);
       bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
 
 #ifdef COGL_HAS_GTYPE_SUPPORT
       g_type_init ();
